%newton_cooling

%Use water cooling in a polystyrene cup as an example

%Thermal conductivity /Wm^-1K^-1
k = 2.0;

%Specific heat capacity of water /Jkg^-1K^-1
c = 4181;

%Initial temperature /degrees Celcius
T0 = 90;

%Air temperature /degrees Celcius
Ta = 20;

%Thickness of vessel /m
dx = 0.5*1e-2;

%Mass of fluid /kg
m = 1;

%Density of fluid /kgm^-3
rho = 1000;

%Volume of fluid /m^3
V = m/rho;

%Surface area of vessel /m^2
%Assume cubical vessel, but bottom face not exposed
A = 5*( V^(2/3) );

%Compute time constant /s
tor = m*c*dx/(k*A);

%Define time and temperature vectors
N=20;
t = linspace(0,3*tor,N);
T = Ta +(T0-Ta)*exp( - t/tor );

%Plot graph
fsize = 18;
figure('name','Newton Cooling','color',[1 1 1])
plot(t/60,T);
ylim([0,100]);
xlim([0,3*tor/60])
xticks = 0:2:round(3*tor/60);
set(gca,'xtick',xticks)
grid on;
xlabel('time /mins','fontsize',fsize);
ylabel('T / ^oC','fontsize',fsize);
title('Newtonian Cooling','fontsize',fsize);
set(gca,'fontsize',fsize)
print( gcf, 'newton cooling','-dpng','-r300' );
close(gcf);

%Export data to Excel
data{1,1} = ['Newtonian Cooling. Ta = ',num2str(Ta)];
data{2,1} = 'time /s';
data{2,2} = 'Temperature /degrees Celcius';
data{2,3} = 'A*t/(m*c*dx)';
data{2,4} = 'ln( (T-Ta)/(T0-Ta) )';
for n=1:N
    data{2+n,1} = t(n);
    data{2+n,2} = T(n);
    data{2+n,3} = A*t(n)/(m*c*dx);
    data{2+n,4} = log( (T(n)-Ta)/(T0-Ta) );
end
xlswrite( 'newton_cool.xls',data );

%End of code
